import 'package:flutter/material.dart';
import 'package:payment_lib/src/payment_method/payment_method_item.dart';

class PaymentMethodCard extends StatefulWidget {
  const PaymentMethodCard({
    Key? key,
    required this.categoryName,
    required this.payments,
    this.onChanged,
    this.initTotalPayment = 3,
    required this.selectPaymentMethod,
  }) : super(key: key);

  final String categoryName;
  final List<dynamic> payments;
  final Function(String? value)? onChanged;
  final int initTotalPayment;
  final ValueNotifier<String?> selectPaymentMethod;

  @override
  State<PaymentMethodCard> createState() => _PaymentMethodCardState();
}

class _PaymentMethodCardState extends State<PaymentMethodCard> {
  final showAll = ValueNotifier<bool>(false);

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
      valueListenable: widget.selectPaymentMethod,
      builder: (context, s, f) => Card(
        shape: const RoundedRectangleBorder(),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 20),
              child: Text(widget.categoryName,
                  style: Theme.of(context)
                      .textTheme
                      .bodyText1!
                      .copyWith(fontWeight: FontWeight.w600)),
            ),
            ValueListenableBuilder(
              valueListenable: showAll,
              builder: (context, _, __) => Column(
                  children: List.generate(widget.payments.length, (index) {
                if (showAll.value) {
                  return Column(children: [
                    PaymentMethodItem(
                      paymentMethodModel: widget.payments[index],
                      selectPaymentMethod: widget.selectPaymentMethod,
                      onChanged: widget.onChanged,
                    ),
                    if (widget.payments.length - 1 != index)
                      const Divider(
                        height: 0,
                      )
                  ]);
                }
                return Column(
                  children: [
                    if (index < widget.initTotalPayment)
                      PaymentMethodItem(
                        paymentMethodModel: widget.payments[index],
                        selectPaymentMethod: widget.selectPaymentMethod,
                        onChanged: widget.onChanged,
                      ),
                    if (index != widget.payments.length - 1)
                      const Divider(
                        height: 0,
                      ),
                    if (index == widget.initTotalPayment)
                      TextButton(
                        onPressed: () {
                          showAll.value = true;
                        },
                        child: Text(
                          'Lihat ${widget.payments.length - widget.initTotalPayment} pembayaran lainnya',
                          textAlign: TextAlign.center,
                        ),
                      ),
                  ],
                );
              })),
            ),
          ],
        ),
      ),
    );
  }
}
