import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:payment_lib/payment_lib.dart';

enum ButtonType { one, two }

class PaymentMethodListView extends StatelessWidget {
  const PaymentMethodListView({
    Key? key,
    required this.paymentMethod,
    required this.selectPaymentMethod,
    this.textButtonStyle,
    this.buttonStyle,
    this.textButton = 'Pilih',
    this.buttonType = ButtonType.one,
    this.onTap,
  }) : super(key: key);

  final List<dynamic> paymentMethod;
  final ValueNotifier<String?> selectPaymentMethod;
  final TextStyle? textButtonStyle;
  final ButtonStyle? buttonStyle;
  final String textButton;
  final ButtonType buttonType;
  final Function()? onTap;

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: ValueListenableBuilder(
        valueListenable: selectPaymentMethod,
        builder: (context, _, __) => Column(
          children: [
            Expanded(
              child: ListView.builder(
                itemCount: paymentMethod.length,
                itemBuilder: (context, i) => PaymentMethodCard(
                  selectPaymentMethod: selectPaymentMethod,
                  categoryName: paymentMethod[i].paymentTypes.name,
                  payments: paymentMethod[i].payments,
                  onChanged: (id) {
                    selectPaymentMethod.value = id!;
                    log(selectPaymentMethod.value!);
                  },
                ),
              ),
            ),
            if (selectPaymentMethod.value != null)
              (buttonType == ButtonType.one)
                  ? Card(
                      margin: EdgeInsets.zero,
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: ElevatedButton(
                          style: buttonStyle ??
                              ElevatedButton.styleFrom(
                                  minimumSize: const Size(double.infinity, 50)),
                          onPressed: onTap,
                          child: Text(textButton,
                              style: textButtonStyle ??
                                  Theme.of(context)
                                      .textTheme
                                      .button!
                                      .copyWith(color: Colors.white)),
                        ),
                      ),
                    )
                  : ElevatedButton(
                      onPressed: onTap,
                      style: buttonStyle ??
                          ElevatedButton.styleFrom(
                              shape: const RoundedRectangleBorder(),
                              minimumSize: const Size(double.infinity, 50)),
                      child: Row(
                        children: [
                          const Spacer(),
                          Text(textButton,
                              style: textButtonStyle ??
                                  Theme.of(context)
                                      .textTheme
                                      .button!
                                      .copyWith(color: Colors.white)),
                          const Spacer(),
                          const Icon(Icons.check),
                        ],
                      ),
                    )
          ],
        ),
      ),
    );
  }
}
