import 'package:fluentui_system_icons/fluentui_system_icons.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:payment_lib/src/extension/currency_format.dart';

class BillDetailsCard extends StatelessWidget {
  const BillDetailsCard({
    Key? key,
    required this.imageUrl,
    required this.paymentName,
    required this.virtualAccountNumber,
    required this.billTotal,
    required this.invoiceNumber,
  }) : super(key: key);
  final String imageUrl;
  final String paymentName;
  final String virtualAccountNumber;
  final int billTotal;
  final String invoiceNumber;

  @override
  Widget build(BuildContext context) {
    return Column(children: [
      Container(
        padding: const EdgeInsets.symmetric(horizontal: 20),
        color: Theme.of(context).colorScheme.surface,
        child: Column(
          children: [
            Row(
              children: [
                Image.network(
                  imageUrl,
                  width: 50,
                  height: 50,
                  fit: BoxFit.contain,
                ),
                const SizedBox(width: 10),
                Text(
                  paymentName,
                  style: Theme.of(context)
                      .textTheme
                      .subtitle2!
                      .copyWith(fontWeight: FontWeight.w600),
                ),
              ],
            ),
          ],
        ),
      ),
      const SizedBox(height: 1),
      Container(
        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
        width: double.infinity,
        color: Theme.of(context).colorScheme.surface,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      Get.locale == null
                          ? 'Nomor Virtual Account'
                          : Get.locale == const Locale('id')
                              ? 'Nomor Virtual Account'
                              : 'Virtual Account Number',
                      style: Theme.of(context)
                          .textTheme
                          .subtitle2!
                          .copyWith(fontWeight: FontWeight.w400),
                    ),
                    const SizedBox(height: 5),
                    Text(
                      virtualAccountNumber,
                      style: Theme.of(context)
                          .textTheme
                          .headline6!
                          .copyWith(fontWeight: FontWeight.w700),
                    )
                  ],
                ),
                IconButton(
                  onPressed: () {
                    Clipboard.setData(
                        ClipboardData(text: virtualAccountNumber));
                    HapticFeedback.vibrate();
                    ScaffoldMessenger.of(context).showSnackBar(
                      SnackBar(
                        content:
                            Text("$virtualAccountNumber berhasil disalin!"),
                        duration: const Duration(seconds: 3),
                      ),
                    );
                  },
                  icon: const Icon(
                    FluentIcons.copy_24_regular,
                    size: 30,
                  ),
                )
              ],
            ),
            const SizedBox(height: 15),
            Text(
              Get.locale == null
                  ? 'Total Tagihan'
                  : Get.locale == const Locale('id')
                      ? 'Total Tagihan'
                      : 'Billing Total',
              style: Theme.of(context)
                  .textTheme
                  .subtitle2!
                  .copyWith(fontWeight: FontWeight.w400),
            ),
            const SizedBox(height: 5),
            Text(
              'Rp ${billTotal.toIdrFormat},-',
              style: Theme.of(context)
                  .textTheme
                  .headline6!
                  .copyWith(fontWeight: FontWeight.w700, color: Colors.green),
            )
          ],
        ),
      ),
      const SizedBox(height: 1),
      Container(
        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
        color: Theme.of(context).colorScheme.surface,
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text(
                  Get.locale == null
                      ? 'No. Faktur'
                      : Get.locale == const Locale('id')
                          ? 'No. Faktur'
                          : 'No. Invoice',
                  style: Theme.of(context)
                      .textTheme
                      .subtitle2!
                      .copyWith(fontWeight: FontWeight.w400),
                ),
                Text(
                  invoiceNumber,
                  style: Theme.of(context)
                      .textTheme
                      .subtitle2!
                      .copyWith(fontWeight: FontWeight.w400),
                ),
              ],
            ),
          ],
        ),
      ),
    ]);
  }
}
