import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:payment_lib/payment_lib.dart';
import 'package:payment_lib/src/payment_summary/bill_detail.dart';
import 'package:payment_lib/src/payment_summary/deadline.dart';
import 'package:payment_lib/src/payment_summary/payment_detail.dart';

class PaymentSummaryTypeOne extends StatelessWidget {
  const PaymentSummaryTypeOne({
    Key? key,
    required this.paymentSummaryModel,
    this.paymentDetail = false,
    this.onTapPaymentDetail,
  }) : super(key: key);

  final dynamic paymentSummaryModel;
  final bool paymentDetail;
  final Function()? onTapPaymentDetail;

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          DeadlineCard(
            deadline: paymentSummaryModel.deadline,
            endTimeRemaining: DateTime.now().add(
              const Duration(hours: 3),
            ),
          ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
            child: Text(
                Get.locale == null
                    ? 'Transfer ke'
                    : Get.locale == const Locale('id')
                        ? 'Transfer ke'
                        : 'Transfer to',
                style: Theme.of(context)
                    .textTheme
                    .subtitle2!
                    .copyWith(fontWeight: FontWeight.bold)),
          ),
          BillDetailsCard(
            imageUrl: paymentSummaryModel.iconUrl,
            invoiceNumber: paymentSummaryModel.invoiceNumber,
            paymentName: paymentSummaryModel.bankName,
            virtualAccountNumber: paymentSummaryModel.accountNumber,
            billTotal: paymentSummaryModel.totalBill,
          ),
          if (paymentDetail)
            PaymentDetailCard(
              onTap: onTapPaymentDetail,
            ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
            child: Text(
              Get.locale == null
                  ? 'Cara Pembayaran'
                  : Get.locale == const Locale('id')
                      ? 'Cara Pembayaran'
                      : 'Payment Instruction',
              style: Theme.of(context)
                  .textTheme
                  .subtitle2!
                  .copyWith(fontWeight: FontWeight.bold),
            ),
          ),
          PaymentInstructionCard(
            paymentIntruction: paymentSummaryModel.paymentIntructions,
          ),
        ],
      ),
    );
  }
}
