import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:payment_lib/payment_lib.dart';

import 'package:payment_lib/src/extension/currency_format.dart';
import 'label_value_col.dart';

enum PaymentCategory { va, retail }

class PaymentSummaryTypeTwo extends StatelessWidget {
  const PaymentSummaryTypeTwo({
    Key? key,
    required this.paymentSummaryModel,
    this.paymentCategory = PaymentCategory.va,
  }) : super(key: key);

  final dynamic paymentSummaryModel;
  final PaymentCategory paymentCategory;

  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 0,
      margin: const EdgeInsets.only(bottom: 5),
      child: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 18, vertical: 8),
              child: Row(
                children: [
                  if (paymentSummaryModel.iconUrl != null)
                    Padding(
                      padding: const EdgeInsets.only(right: 10),
                      child: SizedBox(
                        height: 50,
                        width: 50,
                        child: Image.network(
                          paymentSummaryModel.iconUrl!,
                          fit: BoxFit.contain,
                        ),
                      ),
                    ),
                  Expanded(
                    child: Text(
                      paymentSummaryModel.bankName,
                      style: Theme.of(context).textTheme.bodyText1,
                    ),
                  ),
                ],
              ),
            ),
            Container(
              padding: const EdgeInsets.symmetric(horizontal: 18, vertical: 12),
              color: const Color(0xFFFFEAD8),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(
                    Get.locale == null
                        ? 'Lakukan Pembayaran sebelum:'
                        : Get.locale == const Locale('id')
                            ? "Lakukan pembayaran sebelum:"
                            : 'Make a payment before:',
                    style: Theme.of(context).textTheme.bodyText1!.copyWith(
                          color: Colors.grey[900],
                        ),
                  ),
                  Text(
                    paymentSummaryModel.deadline,
                    style: Theme.of(context).textTheme.bodyText1!.copyWith(
                          color: Colors.deepOrangeAccent,
                          fontWeight: FontWeight.w600,
                        ),
                  ),
                ],
              ),
            ),
            Container(
              padding: const EdgeInsets.all(18),
              color: const Color(0xFFE8FFD9),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  if (paymentSummaryModel.accountNumber != null)
                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Expanded(
                          child: LabelValueCol(
                            label: paymentCategory == PaymentCategory.retail
                                ? "Kode Pembayaran"
                                : "Nomor Virtual Account",
                            labelStyle:
                                Theme.of(context).textTheme.bodyText1!.copyWith(
                                      color: Colors.grey,
                                      fontWeight: FontWeight.w400,
                                    ),
                            value: paymentSummaryModel.accountNumber!,
                            valueStyle: Theme.of(context)
                                .textTheme
                                .headline6!
                                .copyWith(color: Colors.black),
                          ),
                        ),
                        OutlinedButton.icon(
                          onPressed: () {
                            Clipboard.setData(ClipboardData(
                                text: paymentSummaryModel.accountNumber));
                            HapticFeedback.vibrate();
                            ScaffoldMessenger.of(context).showSnackBar(
                              SnackBar(
                                content: Text(
                                    "${paymentSummaryModel.accountNumber} berhasil disalin!"),
                                duration: const Duration(seconds: 3),
                              ),
                            );
                          },
                          icon: const Icon(
                            Icons.copy,
                            size: 18,
                          ),
                          label: const Text("Salin"),
                          style: OutlinedButton.styleFrom(
                            shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(100),
                            ),
                            padding: const EdgeInsets.symmetric(horizontal: 16),
                          ),
                        ),
                      ],
                    ),
                  const SizedBox(height: 10),
                  LabelValueCol(
                    label: "Total Pembayaran",
                    labelStyle: Theme.of(context).textTheme.bodyText1!.copyWith(
                          color: Colors.grey,
                          fontWeight: FontWeight.w400,
                        ),
                    value: (paymentSummaryModel.totalBill as int).toIdrFormat,
                    valueStyle: Theme.of(context)
                        .textTheme
                        .headline6!
                        .copyWith(color: Colors.green),
                  ),
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(18.0),
              child: Row(
                children: [
                  Text(
                    "No. Invoice",
                    style: Theme.of(context).textTheme.bodyText1,
                  ),
                  Expanded(
                    child: Text(
                      paymentSummaryModel.invoiceNumber,
                      textAlign: TextAlign.right,
                      style: Theme.of(context).textTheme.bodyText1,
                    ),
                  ),
                ],
              ),
            ),
            PaymentInstructionCard(
                paymentIntruction: paymentSummaryModel.paymentIntructions),
          ],
        ),
      ),
    );
  }
}
